@@ -4,22 +4,22 @@ from openpyxl import \
     Workbook, \
     load_workbook
 
-from domain.frame.frame_element import FrameElement
-from domain.frame.frame_sheet import FrameSheet
-from domain.motorcycle_model.motorcycle_model import MotorcycleModel
-from domain.motorcycle_model.sheetnames import Sheetnames
+from xlsx_lib.domain.frame.frame_element import FrameElement
+from xlsx_lib.domain.frame.frame_sheet import FrameSheet
+from xlsx_lib.domain.motorcycle_model.motorcycle_model import MotorcycleModel
+from xlsx_lib.domain.motorcycle_model.sheetnames import Sheetnames
 
-from domain.engine.engine_section import EngineSection
-from domain.engine.engine_sheet import EngineSheet
+from xlsx_lib.domain.engine.engine_section import EngineSection
+from xlsx_lib.domain.engine.engine_sheet import EngineSheet
 
-from domain.electronic.electronic_element import ElectronicElement
-from domain.electronic.electronic_sheet import ElectronicSheet
+from xlsx_lib.domain.electronic.electronic_element import ElectronicElement
+from xlsx_lib.domain.electronic.electronic_sheet import ElectronicSheet
 
-from domain.generic_replacements.generic_replacement_sheet import GenericReplacementsSheet
-from domain.generic_replacements.replacement import Replacement
+from xlsx_lib.domain.generic_replacements.generic_replacement_sheet import GenericReplacementsSheet
+from xlsx_lib.domain.generic_replacements.replacement import Replacement
 
-from domain.tightening_torques.tightening_torques_sheet import TighteningTorquesSheet
-from domain.tightening_torques.component import Component
+from xlsx_lib.domain.tightening_torques.tightening_torques_sheet import TighteningTorquesSheet
+from xlsx_lib.domain.tightening_torques.component import Component
 
 sheetnames_relationships = {
     "MOT": Sheetnames.ENGINE,
