@@ -1,4 +1,4 @@
-from domain.tightening_torques.component_part_screw import ComponentPartScrew
+from xlsx_lib.domain.tightening_torques.component_part_screw import ComponentPartScrew
 
 
 class ComponentPart:
