@@ -2,8 +2,8 @@ import os
 import random
 from typing import Optional
 
-from domain.motorcycle_model.motorcycle_model import MotorcycleModel
-from domain.motorcycle_model.motorcycle_model_workbook import MotorcycleModelWorkbook
+from xlsx_lib.domain.motorcycle_model.motorcycle_model import MotorcycleModel
+from xlsx_lib.domain.motorcycle_model.motorcycle_model_workbook import MotorcycleModelWorkbook
 import glob
 
 
